Structs
- Extraction
Result - Result of extracting barcodes from a single read’s sequence and quality.
- Regex
Pattern - Regex-method pattern using named capture groups.
- String
Pattern - String-method pattern using fixed-position characters.
Enums
- Barcode
Pattern - A parsed barcode pattern that knows how to extract UMI/cell/sample bases from a read.
- Prime
End - Which end of the read to extract the barcode from (string method only).