pub enum BarcodePattern {
String(StringPattern),
Regex(RegexPattern),
}Expand description
A parsed barcode pattern that knows how to extract UMI/cell/sample bases from a read.
Variants
String(StringPattern)
Regex(RegexPattern)
Implementations
Sourceimpl BarcodePattern
impl BarcodePattern
Sourcepub fn extract(
&self,
sequence: &[u8],
quality: &[u8],
) -> Result<ExtractionResult, ExtractError>
pub fn extract( &self, sequence: &[u8], quality: &[u8], ) -> Result<ExtractionResult, ExtractError>
Errors
Returns error if the read is too short (string method) or doesn’t match (regex method).