pub struct StringPattern { /* private fields */ }Expand description
String-method pattern using fixed-position characters.
Pattern characters:
N— UMI base (extracted to read name)C— Cell barcode base (extracted to read name)X— Sample/discard base (stays in output sequence, removed from barcode region)
Implementations
Sourceimpl StringPattern
impl StringPattern
Sourcepub fn parse(
pattern_str: &str,
prime_end: PrimeEnd,
) -> Result<Self, ExtractError>
pub fn parse( pattern_str: &str, prime_end: PrimeEnd, ) -> Result<Self, ExtractError>
Parse a string-method pattern like NNNXXXXNN.
Errors
Returns error if pattern is empty or contains characters other than N, X, C.
Sourcepub fn extract(
&self,
sequence: &[u8],
quality: &[u8],
) -> Result<ExtractionResult, ExtractError>
pub fn extract( &self, sequence: &[u8], quality: &[u8], ) -> Result<ExtractionResult, ExtractError>
Extract barcodes from a read’s sequence and quality strings.
Errors
Returns error if the read is shorter than the pattern.