Module pattern

Module pattern 

Structs

ExtractionResult
Result of extracting barcodes from a single read’s sequence and quality.
RegexPattern
Regex-method pattern using named capture groups.
StringPattern
String-method pattern using fixed-position characters.

Enums

BarcodePattern
A parsed barcode pattern that knows how to extract UMI/cell/sample bases from a read.
PrimeEnd
Which end of the read to extract the barcode from (string method only).